@@ -699,24 +699,56 @@ def files_write( fp_source , fp_target = False ) :
     s_util.file_settimes( fp_target , fd[ "fm" ] )
 
 
+def files_append( fp_source , fp_target = False ) :
+
+    if( fp_target == False ) :
+        fp_target = fp_source
+
+    fd = files_read( fp_source )
+
+    fp_target_tmp = fp_target + s_util.uhash( )
+
+
+    ######################
+    # COPY current file to tmp file
+    # Append new contents
+    ######################
+
+    if s_util.file_exists( fp_target ) :
+        s_log.write( "fp_target exists! " + fp_target )
+        with open( fp_target , "ab" ) as f :
+            f.write( fd[ "fc" ] )
+
+    else :
+
+        with open( fp_target_tmp , "wb" ) as f :
+            f.write( fd[ "fc" ] )
+
+        s_util.file_replace( fp_target_tmp , fp_target )
+
+    s_util.file_settimes( fp_target , fd[ "fm" ] )
+
+
 # with open( dir_cache + "local_out.png" , "wb" ) as f :
 #def files_write( fp ) :
 #    # FIXME TODO test this... with open( dir_cache + "local_out.png" , "wb" ) as f :
 #    with open( fp , "w" , 1 ) as f :
 #        f.write( files_getcontent( fp ) )
 
-def files_restore( rpath = False ) :
+def files_restore( rpath = False , mode = "overwrite" ) :
+
     db_files = files_readallmeta( )
-    s_log.write(db_files)
+    s_log.write( db_files )
+    
     for db_file in db_files :
 
         fp_source = db_file[ "fp" ]
 
-        if(rpath!=False):
+        if( rpath != False ) :
             # FIXME TODO WARNING this removes "chars"!
-            fp_target=rpath.rstrip("/")+ "/" + fp_source
-        else:
-            fp_target=fp_source
+            fp_target = rpath.rstrip( "/" ) + "/" + fp_source
+        else :
+            fp_target = fp_source
 
         #s_log.write(fp_source+" -> "+fp_target)
 
@@ -725,8 +757,11 @@ def files_restore( rpath = False ) :
         dp_path = Path( dp )
         dp_path.mkdir( parents = True , exist_ok = True )
 
-
-        files_write( fp_source,fp_target)
+        if mode == "overwrite" :
+            files_write( fp_source , fp_target )
+        
+        if mode == "append" :
+            files_append( fp_source , fp_target )
 
 #        with open( fp_target , "wb" ) as f :
 #            f.write( files_getcontent( fp_source ) )
