@@ -113,13 +113,11 @@ def num_randomlist( s = 10 ) :
     return(random_list)
 
 # Get arg from position and use default
-def argv_get( p , d ) :
-    al=len( sys.argv )-1
-    print(al)
-    if(p>al): return(d)
-
-
-    return(sys.argv[p])
+def argv_get( p , d = None ) :
+    al = len( sys.argv ) - 1
+    #print( al )
+    if( p > al ) : return( d )
+    return( sys.argv[ p ] )
 
 # FIXME TODO aaarrggghhh!!!
 def time_getisoformat( ) :
@@ -191,16 +189,35 @@ def pathnotallowed( p ) :
 
     return( True )
 
+
+def get_hashkeycontentdir( ) :
+    # FIXME TODO should be coming from config
+    fd = "/tmp/sapiadapter/sessions/"
+
+    if( dir_exists( "/data/" ) ) :
+        fd = "/data/sessions/"
+
+    return( fd )
+
 def save_hashkeycontent( fk , fc ) :
-    fp = "/tmp/" + hash( fk ) + ".tmp"
-    with open( fp , "w" ) as file:
+    
+    fd = get_hashkeycontentdir( )
+
+    path_mkdirs( fd )
+
+    fp = fd + hash( fk ) + ".session"
+    with open( fp , "w" ) as file :
         file.write( fc )
 
 def load_hashkeycontent( fk ) :
-    fp = "/tmp/" + hash( fk ) + ".tmp"
-    if(file_exists(fp)):
-        return(file_read(fp))
-    return(False)
+    
+    fd = get_hashkeycontentdir( )
+
+    fp = fd + hash( fk ) + ".session"
+
+    if( file_exists( fp ) ) :
+        return( file_read( fp ) )
+    return( False )
 
 
 
@@ -605,7 +622,7 @@ def file_read(fp):
     return(open( fp , "r" ).read( ))
 
 def file_exists( fp ) :
-    return( os.path.isfile(fp) )
+    return( os.path.isfile( fp ) )
 
 def file_ctime( fp ) :
     if(not file_exists(fp)): return(False)
